EXPORTS
	??1CCameraInfoPlugin@@UAE@XZ @ 1 NONAME ; CCameraInfoPlugin::~CCameraInfoPlugin(void)
	??1CCameraPlugin@@MAE@XZ @ 2 NONAME ; CCameraPlugin::~CCameraPlugin(void)
	?CamerasAvailable@CCameraPlugin@@KAHXZ @ 3 NONAME ; int CCameraPlugin::CamerasAvailable(void)
	?NewDuplicateL@CCameraPlugin@@KAPAV1@AAVMCameraObserver@@H@Z @ 4 NONAME ABSENT
	?NewL@CCameraPlugin@@KAPAV1@AAVMCameraObserver@@H@Z @ 5 NONAME ABSENT
	?NewDuplicateL@CCameraPlugin@@KAPAV1@AAVMCameraObserver2@@H@Z @ 6 NONAME ABSENT
	?NewL@CCameraPlugin@@KAPAV1@AAVMCameraObserver2@@HH@Z @ 7 NONAME ABSENT
	??0CCameraInfoPlugin@@IAE@XZ @ 8 NONAME ; CCameraInfoPlugin::CCameraInfoPlugin(void)
	??0CCameraPlugin@@IAE@XZ @ 9 NONAME ; CCameraPlugin::CCameraPlugin(void)
	?CameraVersion@CCameraPlugin@@IAEHXZ @ 10 NONAME ; int CCameraPlugin::CameraVersion(void)
	?NewDuplicateL@CCameraPlugin@@KAPAV1@AAVMCameraObserver2@@HH@Z @ 11 NONAME ; class CCameraPlugin * CCameraPlugin::NewDuplicateL(class MCameraObserver2 &, int, int)
	?NewDuplicateL@CCameraPlugin@@KAPAV1@AAVMCameraObserver@@HH@Z @ 12 NONAME ; class CCameraPlugin * CCameraPlugin::NewDuplicateL(class MCameraObserver &, int, int)
	?NewL@CCameraPlugin@@KAPAV1@AAVMCameraObserver2@@HHH@Z @ 13 NONAME ; class CCameraPlugin * CCameraPlugin::NewL(class MCameraObserver2 &, int, int, int)
	?NewL@CCameraPlugin@@KAPAV1@AAVMCameraObserver@@HH@Z @ 14 NONAME ; class CCameraPlugin * CCameraPlugin::NewL(class MCameraObserver &, int, int)

